@@ -1,4 +1,4 @@
-require File.dirname(__FILE__) + '/spec_helper'
+require 'spec_helper'
 
 describe "HAML" do
   it "should be able to render HAML templates" do
@@ -6,12 +6,12 @@ describe "HAML" do
     c.body.should == ::Haml::Engine.new("#foo\n  %p Hello").render
   end
 
-  it "should be able to render HAML templates" do
+  it "should be able to render HAML templates with locals" do
     c = dispatch_to(PartialHaml, :index)
     c.body.should == ::Haml::Engine.new("#foo\n  %p Partial").render
   end
 
-  it "should use the haml configuration in Merb::Config" do
+  it "should use the haml configuration in Merb::Plugins.config" do
     c = dispatch_to(HamlConfig, :index)
     c.body.should == ::Haml::Engine.new("#foo\n  %foo", :autoclose => ["foo"]).render
   end
